<?php 
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if( !class_exists('WPEPDisplayPopup')) :
	
	final class WPEPDisplayPopup{

		private $wpep_settings;
	
		function __construct(){
			$wpep_settings = get_option("wpep_settings");
			$this->wpep_settings = $wpep_settings;
			add_action('wp_enqueue_scripts', array($this,'loadScripts'));
			add_filter('popup_content' , array($this , 'get_popup_content'));
			add_action('wp_head', array($this , 'print_ajax_url'));
			if(isset($wpep_settings['mailchimp_enabled']) && $wpep_settings['mailchimp_enabled'] == 'mailchimp') {
				
				add_action( 'wp_ajax_subscribe_user', array($this , 'subscribe_user') );
				add_action( 'wp_ajax_nopriv_subscribe_user', array($this , 'subscribe_user') );
			}
		}
		
		function print_ajax_url() { ?>
			<script type="text/javascript">
			var ajaxurl = '<?php echo admin_url('admin-ajax.php'); ?>';
			</script>
		<?php 
		}
		
		function subscribe_user() {
			$MailChimp = new MailChimp($this->wpep_settings['mailchimp_api_key']);
			$args =  array(
					'id'                => $this->wpep_settings['mailchimp_list'],
					'email'             => array('email'=>sanitize_email($_POST['email'])),
					'double_optin'      => false,
					'update_existing'   => true,
					'replace_interests' => false,
					'send_welcome'      => false,
			);
			$result = $MailChimp->call('lists/subscribe',$args);
			die();
		}
		
		function loadScripts(){
		
			$wpep_settings = get_option('wpep_settings');
			$wpep_display_popup_count = $wpep_settings['wpep_display_popup'];
				
		if(!(isset($_COOKIE['ck_glue_visit']) && $_COOKIE['ck_glue_visit'] == $wpep_display_popup_count))
		{
			wp_enqueue_script( 'jquery' );
			wp_register_style('wpep_display_popup_css',WPEKA_WPEP_PLUGIN_URL."assets/css/jquery.glue.css");
			wp_enqueue_style('wpep_display_popup_css');
			wp_register_script('wpep_display_popup_js',WPEKA_WPEP_PLUGIN_URL."assets/js/jquery.glue.min.js");
			wp_register_script('wpep_mailchimp_popup_js',WPEKA_WPEP_PLUGIN_URL."assets/js/mailchimp.js");
			wp_enqueue_script('wpep_display_popup_js');
			wp_enqueue_style('google_font' , 'http://fonts.googleapis.com/css?family=Comfortaa:400,700,300');
			wp_enqueue_script('wpep_mailchimp_popup_js');
		}
			$wpep_settings = get_option('wpep_settings');
			if(is_user_logged_in() && $wpep_settings['popup_display']=='1')
				add_action( 'wp_footer', array( $this, 'showPopup') );
			if(!is_user_logged_in() && $wpep_settings['popup_display']=='2')
			{
				if(is_page(array('pricing','web-slider-features')))
				{
				add_action( 'wp_footer', array( $this, 'showPopup') );
				}
			}
			if((is_user_logged_in() || !is_user_logged_in() ) && $wpep_settings['popup_display']=='3')
				add_action( 'wp_footer', array( $this, 'showPopup') );
			if($wpep_settings['wpep_popuptype']=="corner")
			{
				include("custom.php");
			}
		}
		
		function get_popup_content($content) {

			$wpep_settings = get_option('wpep_settings');
			if($wpep_settings['wpep_popuptype']=="corner")
			{
				$glue_content = stripslashes($wpep_settings['wpep_corner_message']);
			}
			if($wpep_settings['wpep_popuptype']=="on_screen")
			{
				$glue_content = stripslashes($wpep_settings['wpep_message']);
			}
			return html_entity_decode($glue_content);
		}
		
		function showPopup(){
			$wpep_settings = get_option('wpep_settings');
			$wpep_display_popup_count = $wpep_settings['wpep_display_popup'];
			$enable_cookie = $wpep_display_popup_count==0?"false":"true";
			
			$glue_content = '';
			if(isset($_COOKIE['ck_glue_visit']) && $_COOKIE['ck_glue_visit'] == $wpep_display_popup_count)
			{
				return 0;
			}
			echo '<script>
			
		jQuery(document).ready(function(){
			jQuery.glue({
				layer: "#beforeyougo",
				trigger :["'.$wpep_settings['wpep_position'].'"],
				maxamount :'.$wpep_display_popup_count.',
				cookie : '.$enable_cookie.'		
			});
		});
	</script>';
			?>
			<div id="beforeyougo" class="glue_popup">
				<div class="glue_close" onclick="jQuery.glue_close()">X</div>
				<div class="glue_content">
				<?php echo apply_filters('popup_content' , $glue_content); ?>
				</div>
			</div>
			<?php 
		
		}
	}

new WPEPDisplayPopup();

endif;
?>
